summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--common.nix6
1 files changed, 2 insertions, 4 deletions
diff --git a/common.nix b/common.nix
index 99d1b21..f916914 100644
--- a/common.nix
+++ b/common.nix
@@ -149,8 +149,9 @@ in
# OpenSSH daemon config
services.openssh = {
# enable with public key only auth
enable = true;
+ startWhenNeeded = true;
settings.PasswordAuthentication = false;
settings.KbdInteractiveAuthentication = false;
@@ -427,9 +428,6 @@ in
services.printing.enable = true;
services.printing.drivers = [ pkgs.hplip ];
- # let's get SSD status
- services.smartd.enable = true;
-
# dconf is needed for gtk, see https://nixos.wiki/wiki/KDE
programs.dconf.enable = true;
@@ -149,8 +149,9 @@ in
# OpenSSH daemon config
services.openssh = {
- # enable with public key only auth
+ # enable with public key only auth, start on demand only
enable = true;